@@ -182,16 +182,11 @@ class RechargeSubscription(RechargeResource):
     """
     object_list_key = 'subscriptions'
 
-    def cancel(self, subscription_id, reason='Other', send_email=False):
+    def cancel(self, subscription_id, data=None):
         """Cancel a subsciption.
         https://developer.rechargepayments.com/#cancel-subscription
         """
-        return self.http_post(
-            f'{self.url}/{subscription_id}/cancel', {
-                'cancellation_reason': reason,
-                'send_email': send_email
-            }
-        )
+        return self.http_post(f'{self.url}/{subscription_id}/cancel', data)
 
     def delete(self, subscription_id):
         """Delete a subscription
@@ -221,3 +216,16 @@ class RechargeOnetime(RechargeResource):
         https://developer.rechargepayments.com/#delete-a-onetime
         """
         return self.http_delete(f'{self.url}/{onetime_id}')
+
+
+class RechargeDiscount(RechargeResource):
+    """
+    https://developer.rechargepayments.com/#discounts
+    """
+    object_list_key = 'discounts'
+
+    def delete(self, discount_id):
+        """Delete a Discount
+        https://developer.rechargepayments.com/#delete-a-discount
+        """
+        return self.http_delete(f'{self.url}/{discount_id}')
\ No newline at end of file
